pub enum MemoryMode {
Disabled,
Permissive,
Strict,
}Expand description
Bounds validation and global memory limiter behavior.
Variants
Disabled
Bounds validation is skipped, and no memory limiting is applied.
Permissive
Treat bounds validation failures as non-fatal.
Global memory limiter will be enabled and active if a memory limit is configured.
Strict
Treat bounds validation failures as fatal.
Global memory limiter will be enabled and active if a memory limit is configured.