pub fn initialize_memory_bounds(
configuration: MemoryBoundsConfiguration,
component_registry: ComponentRegistryHandle,
) -> Result<MemoryLimiter, GenericError>Expand description
Initializes the memory bounds system and verifies any configured bounds based on the configured memory mode.
See MemoryMode for details on the behavior of each mode.
Errors
If the bounds could not be validated under MemoryMode::Strict, or if the configured grant is invalid, an error
is returned.